A small library for asserting constant parameters for macros at compile time. Please look at tests for example usage.
A small library for asserting constant parameters for macros at compile time. Please look at tests for example usage.
(assert-keys check-map valid-keys)Called from inside a macro. Validates keys at compile-time.
Called from inside a macro. Validates keys at compile-time.
(assert-value v valid-keys)Called from inside a macro. Validates a parameter at compile-time.
Called from inside a macro. Validates a parameter at compile-time.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |